@@ -287,6 +287,14 @@ def pat():
     input = parse_json['ukraine']
     return input
 
+def alerts():
+    url = "https://www.programmershouse-api.ga/alerts"
+    response = requests.get(url)
+    data = response.text
+    parse_json = json.loads(data)
+    input = parse_json['ukraine']
+    return input
+
 def wink()->str:
     url = "https://www.programmershouse-api.ga/wink"
     response = requests.get(url)
